@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-error-viewer-extension.c,v 1.21 2005/01/13 16:15:47 chpe Exp $
+ *  $Id: ephy-error-viewer-extension.c,v 1.26 2005/05/29 19:18:47 chpe Exp $
  */
 
 #include "config.h"
@@ -89,7 +89,7 @@ static void ephy_error_viewer_extension_validate	(GtkAction *action,
 static void ephy_error_viewer_extension_check_links	(GtkAction *action,
 							 ErrorViewerCBData *data);
 
-static GtkActionEntry action_entries [] =
+static const GtkActionEntry action_entries [] =
 {
 #ifdef HAVE_OPENSP
 	{ "SgmlValidate",
@@ -112,7 +112,6 @@ static GtkActionEntry action_entries [] =
 	  N_("Display web page errors"),
 	  G_CALLBACK (ephy_error_viewer_extension_show_viewer) }
 };
-static const guint n_action_entries = G_N_ELEMENTS (action_entries);
 
 static GObjectClass *parent_class = NULL;
 
@@ -163,7 +162,7 @@ ephy_error_viewer_extension_register_type (GTypeModule *module)
 static void
 ephy_error_viewer_extension_init (EphyErrorViewerExtension *extension)
 {
-	LOG ("EphyErrorViewerExtension initialising")
+	LOG ("EphyErrorViewerExtension initialising");
 
 	ephy_embed_shell_get_embed_single (embed_shell); /* Fire up Mozilla */
 
@@ -189,7 +188,7 @@ ephy_error_viewer_extension_finalize (GObject *object)
 	EphyErrorViewerExtension *extension =
 		EPHY_ERROR_VIEWER_EXTENSION (object);
 
-	LOG ("EphyErrorViewerExtension finalizing")
+	LOG ("EphyErrorViewerExtension finalizing");
 
 	mozilla_unregister_error_listener (extension->priv->listener);
 
@@ -341,23 +340,19 @@ switch_page_cb (GtkNotebook *notebook,
 }
 
 static void
-tab_added_cb (GtkWidget *notebook,
-	      EphyTab *tab,
-	      EphyWindow *window)
+impl_attach_tab (EphyExtension *extension,
+		 EphyWindow *window,
+		 EphyTab *tab)
 {
-	g_return_if_fail (EPHY_IS_TAB (tab));
-
 	g_signal_connect_after (tab, "notify::load-status",
 				G_CALLBACK (load_status_cb), window);
 }
 
 static void
-tab_removed_cb (GtkWidget *notebook,
-		EphyTab *tab,
-		EphyWindow *window)
+impl_detach_tab (EphyExtension *extension,
+		 EphyWindow *window,
+		 EphyTab *tab)
 {
-	g_return_if_fail (EPHY_IS_TAB (tab));
-
 	g_signal_handlers_disconnect_by_func
 		(tab, G_CALLBACK (load_status_cb), window);
 }
@@ -385,7 +380,7 @@ impl_attach_window (EphyExtension *extension,
 	guint merge_id;
 	WindowData *data;
 
-	LOG ("EphyErrorViewerExtension attach_window")
+	LOG ("EphyErrorViewerExtension attach_window");
 
 	cb_data = g_new (ErrorViewerCBData, 1);
 	cb_data->extension = EPHY_ERROR_VIEWER_EXTENSION (extension);
@@ -399,7 +394,7 @@ impl_attach_window (EphyExtension *extension,
 		gtk_action_group_new ("EphyErrorViewerExtensionActions");
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
 	gtk_action_group_add_actions_full (action_group, action_entries,
-					   n_action_entries, cb_data,
+					   G_N_ELEMENTS (action_entries), cb_data,
 					   free_error_viewer_cb_data);
 
 	gtk_ui_manager_insert_action_group (manager, action_group, 0);
@@ -427,10 +422,6 @@ impl_attach_window (EphyExtension *extension,
 #ifdef HAVE_OPENSP
 	notebook = ephy_window_get_notebook (window);
 
-	g_signal_connect_after (notebook, "tab_added",
-				G_CALLBACK (tab_added_cb), window);
-	g_signal_connect_after (notebook, "tab_removed",
-				G_CALLBACK (tab_removed_cb), window);
 	g_signal_connect_after (notebook, "switch_page",
 				G_CALLBACK (switch_page_cb), window);
 #endif /* HAVE_OPENSP */
@@ -444,7 +435,6 @@ impl_detach_window (EphyExtension *extension,
 	WindowData *data;
 #ifdef HAVE_OPENSP
 	GtkWidget *notebook;
-	GList *tabs, *l;
 #endif /* HAVE_OPENSP */
 
 	/* Remove UI */
@@ -462,19 +452,8 @@ impl_detach_window (EphyExtension *extension,
 	/* Remove notification signals for HTML/link checking */
 	notebook = ephy_window_get_notebook (window);
 
-	g_signal_handlers_disconnect_by_func
-		(notebook, G_CALLBACK (tab_added_cb), window);
-	g_signal_handlers_disconnect_by_func
-		(notebook, G_CALLBACK (tab_removed_cb), window);
 	g_signal_handlers_disconnect_by_func
 		(notebook, G_CALLBACK (switch_page_cb), window);
-
-	tabs = ephy_window_get_tabs (window);
-	for (l = tabs; l != NULL; l = l->next)
-	{
-		tab_removed_cb (notebook, (EphyTab *) l->data, window);
-	}
-	g_list_free (tabs);
 #endif /* HAVE_OPENSP */
 }
 
@@ -483,4 +462,8 @@ ephy_error_viewer_extension_iface_init (EphyExtensionIface *iface)
 {
 	iface->attach_window = impl_attach_window;
 	iface->detach_window = impl_detach_window;
+#ifdef HAVE_OPENSP
+	iface->attach_tab = impl_attach_tab;
+	iface->detach_tab = impl_detach_tab;
+#endif /* HAVE_OPENSP */
 }
