@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gesture.h,v 1.2 2004/01/15 23:04:04 chpe Exp $
+ *  $Id: ephy-gesture.h,v 1.3 2005/08/28 12:30:03 chpe Exp $
  */
 
 #ifndef EPHY_GESTURE_H
@@ -37,8 +37,8 @@ G_BEGIN_DECLS
 #define EPHY_IS_GESTURE_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), EPHY_TYPE_GESTURE))
 #define EPHY_GESTURE_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), EPHY_TYPE_GESTURE, EphyGestureClass))
 
-typedef struct _EphyGesture		EphyGesture;
 typedef struct _EphyGestureClass	EphyGestureClass;
+typedef struct _EphyGesture		EphyGesture;
 typedef struct _EphyGesturePrivate	EphyGesturePrivate;
 
 struct _EphyGestureClass 
@@ -60,15 +60,20 @@ GType		ephy_gesture_get_type		(void);
 
 GType		ephy_gesture_register_type	(GTypeModule *module);
 
-EphyGesture    *ephy_gesture_new		(GtkWidget *window,
-						 EphyEmbedEvent *event);
-
-void		ephy_gesture_start		(EphyGesture *gesture);
+EphyGesture    *ephy_gesture_new		(GtkWidget *window);
 
 GtkWidget      *ephy_gesture_get_window		(EphyGesture *gesture);
 
+gboolean	ephy_gesture_start		(EphyGesture *gesture);
+
+void		ephy_gesture_stop		(EphyGesture *gesture,
+						 guint32 time);
+
 EphyEmbedEvent *ephy_gesture_get_event		(EphyGesture *gesture);
 
+void		ephy_gesture_set_event		(EphyGesture *gesture,
+						 EphyEmbedEvent *event);
+
 G_END_DECLS
 
 #endif
