@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-page-info-extension.c,v 1.16 2005/01/28 22:30:13 chpe Exp $
+ *  $Id: ephy-page-info-extension.c,v 1.17.4.1 2005/09/24 12:10:49 chpe Exp $
  */
 
 #include "config.h"
@@ -37,7 +37,7 @@
 #include <glib/gi18n-lib.h>
 
 #define WINDOW_DATA_KEY "EphyPageInfoExtensionWindowData"
-#define MENU_PATH "/menubar/ToolsMenu"
+#define MENU_PATH "/menubar/ViewMenu"
 
 #define EPHY_PAGE_INFO_EXTENSION_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_PAGE_INFO_EXTENSION, EphyPageInfoExtensionPrivate))
 
@@ -58,16 +58,15 @@ static void ephy_page_info_extension_init	(EphyPageInfoExtension *extension);
 static void ephy_page_info_extension_display_cb (GtkAction *action,
 						 EphyWindow *window);
 
-static GtkActionEntry action_entries [] =
+static const GtkActionEntry action_entries [] =
 {
 	{ "PageInfo",
 	  NULL,
-	  N_("_Page Info"),
+	  N_("Pa_ge Information"),
 	  NULL,
 	  N_("Display page information in a dialog"),
 	  G_CALLBACK (ephy_page_info_extension_display_cb) },
 };
-static const guint n_action_entries = G_N_ELEMENTS (action_entries);
 
 static GObjectClass *parent_class = NULL;
 static GType type = 0;
@@ -244,7 +243,7 @@ impl_attach_window (EphyExtension *extension,
 		gtk_action_group_new ("EphyPageInfoExtensionActions");
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
 	gtk_action_group_add_actions (action_group, action_entries,
-				      n_action_entries, window);
+				      G_N_ELEMENTS (action_entries), window);
 
 	gtk_ui_manager_insert_action_group (manager, action_group, -1);
 
@@ -253,15 +252,9 @@ impl_attach_window (EphyExtension *extension,
 	g_object_set_data_full (G_OBJECT (window), WINDOW_DATA_KEY, data,
 				(GDestroyNotify) free_window_data);
 
-	gtk_ui_manager_add_ui (manager, ui_id, MENU_PATH,
-			       "PageInfoSep", NULL,
-			       GTK_UI_MANAGER_SEPARATOR, FALSE);
-	gtk_ui_manager_add_ui (manager, ui_id, MENU_PATH,
+	gtk_ui_manager_add_ui (manager, ui_id, MENU_PATH "/ViewPageSourceMenu",
 			       "PageInfo", "PageInfo",
 			       GTK_UI_MANAGER_MENUITEM, FALSE);
-	gtk_ui_manager_add_ui (manager, ui_id, MENU_PATH,
-			       "PageInfoSep2", NULL,
-			       GTK_UI_MANAGER_SEPARATOR, FALSE);
 
 	notebook = ephy_window_get_notebook (window);
 
